@@ -20,3 +20,15 @@ class SluiceComplex(_Group):
 
 class WeirComplex(_Group):
     element_class: str = Field("WeirComplex", const=True)
+
+
+class GateComplex(_Group):
+    element_class: str = Field("GateComplex", const=True)
+
+
+class Waterfall(_Group):
+    element_class: str = Field("Waterfall", const=True)
+
+
+class Subsystem(_Group):
+    element_class: str = Field("Subsystem", const=True)
