@@ -164,8 +164,8 @@ class ReservoirLongitudinalStation(_Model):
     model: Literal["reservoir"] = Field(
         ..., description="To which models it can be applied"
     )
-    p: float = Field(..., ge=0.0, description="Reservoir equation multiplier")
-    m: float = Field(..., ge=0.5, le=2.5, description="Reservoir equation exponent")
+    p: Union[float, str] = Field(..., description="Reservoir equation multiplier")
+    m: Union[float, str] = Field(..., description="Reservoir equation exponent")
 
 
 class HydrologicRoutingModel(str, enum.Enum):
