@@ -3,11 +3,10 @@ import math
 from typing import Any, Dict
 
 import pytest
-from kisters.network_store.model_library.util import (
+from kisters.network_store.model_library.util import (  # element_to_dict,
     all_links,
     all_nodes,
     element_from_dict,
-    # element_to_dict,
     elements_mapping,
 )
 
@@ -291,7 +290,17 @@ elements = [
         "level_volume": [
             {"level": 0.0, "volume": 0.0},
             {"level": 10.0, "volume": 10.0},
+            {"level": 20.0, "volume": 20.0},
+            {"level": 30.0, "volume": 30.0},
         ],
+        "level_volume_interp": "bspline",
+        "level_capacity": [
+            {"level": 0.0, "capacity": 0.0},
+            {"level": 10.0, "capacity": 10.0},
+            {"level": 20.0, "capacity": 20.0},
+            {"level": 30.0, "capacity": 30.0},
+        ],
+        "level_capacity_interp": "bspline",
         "display_name": "storage",
         "schematic_location": {"x": 1.0, "y": 1.0, "z": 0.0},
         "element_class": "Storage",
